#!/bin/bash

set -eux

apt-get install make autopoint autoconf libtool libattr1.dev musl-tools sbsigntool

wget http://ftp.us.debian.org/debian/pool/main/d/dracut/dracut-core_051-1_amd64.deb
wget http://ftp.us.debian.org/debian/pool/main/d/dracut/dracut_051-1_all.deb
wget http://ftp.us.debian.org/debian/pool/main/d/dracut/dracut-network_051-1_all.deb

apt install ./dracut-core_051-1_amd64.deb ./dracut_051-1_all.deb ./dracut-network_051-1_all.deb

rm dracut-core_051-1_amd64.deb dracut_051-1_all.deb dracut-network_051-1_all.deb

if [ ! -e "$HOME/.cargo/bin" ]; then
  curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh
fi
export PATH=$PATH:$HOME/.cargo/bin
rustup target add x86_64-unknown-linux-musl



if [ ! -e /etc/uefi-key ]; then
  mkdir /etc/uefi-key
fi

if [ ! -e /etc/uefi-key/db.crt ]; then
  openssl req -newkey rsa:2048 -nodes -keyout /etc/uefi-key/db.key -new -x509 -sha256 -days 36500 -subj "/CN=TEST" -out /etc/uefi-key/db.crt
  openssl x509 -outform DER -in /etc/uefi-key/db.crt -out /etc/uefi-key/db.cer
fi


cd dracut.module
make install

cd ..
rm -rf dracut_tmp
mkdir dracut_tmp

disk_info=$(/sbin/fdisk -l | grep '^/dev' | cut -d' ' -f1)

disk_info_list=(${disk_info//' '/})



/sbin/e2label ${disk_info_list[1]} ROOT

rm -rf /boot/efi/EFI/Linux/*
dracut --force  -c ./dracut.module/dracut.conf --confdir dracut_tmp

cp -r /boot/efi/EFI /EFI
#maybe not necessairy
cp /etc/uefi-key/db.cer /EFI/db.cer
cp /etc/uefi-key/db.cer /boot/efi/db.cer
uefi=$(ls /EFI/Linux)

efibootmgr --quiet --create --disk ${disk_info_list[0]} --label 'debian UEFI' --loader /EFI/Linux/$uefi
